"""
backend_statistic_chart automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_statistic_chart_data import BackendStatisticChartData
@dataclass_json
@dataclass
class BackendStatisticChart:
    labels: List[str]
    data: List[BackendStatisticChartData]
    series: List[str]



"""
backend_marketplace_remote_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_marketplace_app import BackendMarketplaceApp
@dataclass_json
@dataclass
class BackendMarketplaceRemoteApp(BackendMarketplaceApp):
    local: BackendMarketplaceApp



"""
consumer_user_password_reset automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerUserPasswordReset:
    token: str
    new_password: str



"""
consumer_grant automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from consumer_app import ConsumerApp
@dataclass_json
@dataclass
class ConsumerGrant:
    id: int
    app: ConsumerApp
    create_date: datetime.datetime



"""
backend_generator_index_provider automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendGeneratorIndexProvider:
    name: str
    _class: str



"""
consumer_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class ConsumerApp:
    id: int
    user_id: int
    status: int
    name: str
    url: str
    app_key: str
    app_secret: str
    date: str
    scopes: List[str]
    metadata: CommonMetadata



"""
backend_sdk_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_sdk_types import BackendSdkTypes
@dataclass_json
@dataclass
class BackendSdkResponse:
    types: BackendSdkTypes



"""
SystemTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from system_connection_tag import SystemConnectionTag
from system_meta_tag import SystemMetaTag
from system_payment_tag import SystemPaymentTag

class SystemTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass

    def payment(self) -> SystemPaymentTag:
        return SystemPaymentTag(
            this.http_client,
            this.parser
        )
    pass

    def meta(self) -> SystemMetaTag:
        return SystemMetaTag(
            this.http_client,
            this.parser
        )
    pass

    def connection(self) -> SystemConnectionTag:
        return SystemConnectionTag(
            this.http_client,
            this.parser
        )
    pass





"""
BackendAuditTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from backend_audit import BackendAudit
from backend_audit_collection import BackendAuditCollection
from common_message_exception import CommonMessageException

class BackendAuditTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def get(self, audit_id: str) -> BackendAudit:
        try:
            pathParams = {}
            pathParams["audit_id"] = audit_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/audit/$audit_id<[0-9]+>", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendAudit.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 410:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_all(self, start_index: int, count: int, search: str, _from: str, to: str, app_id: int, user_id: int, event: str, ip: str, message: str) -> BackendAuditCollection:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["event"] = event
            queryParams["ip"] = ip
            queryParams["message"] = message

            queryStructNames = [];

            url = self.parser.url("/backend/audit", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendAuditCollection.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
common_message automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class CommonMessage:
    success: bool
    message: str
    id: str



"""
BackendLogTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from backend_log import BackendLog
from backend_log_collection import BackendLogCollection
from backend_log_error import BackendLogError
from backend_log_error_collection import BackendLogErrorCollection
from common_message_exception import CommonMessageException

class BackendLogTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def get(self, log_id: str) -> BackendLog:
        try:
            pathParams = {}
            pathParams["log_id"] = log_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/log/$log_id<[0-9]+>", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendLog.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 410:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_all(self, start_index: int, count: int, search: str, _from: str, to: str, route_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendLogCollection:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["routeId"] = route_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/log", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendLogCollection.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_error(self, error_id: str) -> BackendLogError:
        try:
            pathParams = {}
            pathParams["error_id"] = error_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/log/error/$error_id<[0-9]+>", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendLogError.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_all_errors(self, start_index: int, count: int, search: str) -> BackendLogErrorCollection:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search

            queryStructNames = [];

            url = self.parser.url("/backend/log/error", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendLogErrorCollection.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
backend_webhook automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_webhook_response import BackendWebhookResponse
@dataclass_json
@dataclass
class BackendWebhook:
    id: int
    event_id: int
    user_id: int
    name: str
    endpoint: str
    responses: List[BackendWebhookResponse]



"""
BackendCronjobTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from backend_cronjob import BackendCronjob
from backend_cronjob_collection import BackendCronjobCollection
from backend_cronjob_create import BackendCronjobCreate
from backend_cronjob_update import BackendCronjobUpdate
from common_message import CommonMessage
from common_message_exception import CommonMessageException

class BackendCronjobTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def delete(self, cronjob_id: str) -> CommonMessage:
        try:
            pathParams = {}
            pathParams["cronjob_id"] = cronjob_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/cronjob/$cronjob_id<[0-9]+|^~>", pathParams)

            headers = {}

            response = self.http_client.delete(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 410:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def update(self, cronjob_id: str, payload: BackendCronjobUpdate) -> CommonMessage:
        try:
            pathParams = {}
            pathParams["cronjob_id"] = cronjob_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/cronjob/$cronjob_id<[0-9]+|^~>", pathParams)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.put(url, headers=headers, params=this.parser.query(queryParams, queryStructNames), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.from_json(response.content)

            if response.status_code == 400:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 410:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get(self, cronjob_id: str) -> BackendCronjob:
        try:
            pathParams = {}
            pathParams["cronjob_id"] = cronjob_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/cronjob/$cronjob_id<[0-9]+|^~>", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendCronjob.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 410:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def create(self, payload: BackendCronjobCreate) -> CommonMessage:
        try:
            pathParams = {}

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/cronjob", pathParams)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=this.parser.query(queryParams, queryStructNames), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.from_json(response.content)

            if response.status_code == 400:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_all(self, start_index: int, count: int, search: str) -> BackendCronjobCollection:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search

            queryStructNames = [];

            url = self.parser.url("/backend/cronjob", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendCronjobCollection.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
backend_transaction automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendTransaction:
    id: int
    user_id: int
    plan_id: int
    transaction_id: str
    amount: float
    points: float
    period_start: datetime.datetime
    period_end: datetime.datetime
    insert_date: datetime.datetime



"""
SystemMetaTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from common_message_exception import CommonMessageException
from passthru import Passthru
from system_about import SystemAbout
from system_health_check import SystemHealthCheck
from system_route import SystemRoute
from system_schema import SystemSchema

class SystemMetaTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def get_schema(self, name: str) -> SystemSchema:
        try:
            pathParams = {}
            pathParams["name"] = name

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/system/schema/:name", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return SystemSchema.from_json(response.content)

            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 410:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_routes(self, ) -> SystemRoute:
        try:
            pathParams = {}

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/system/route", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return SystemRoute.from_json(response.content)


            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_health(self, ) -> SystemHealthCheck:
        try:
            pathParams = {}

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/system/health", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return SystemHealthCheck.from_json(response.content)


            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_debug(self, payload: Passthru) -> Passthru:
        try:
            pathParams = {}

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/system/debug", pathParams)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=this.parser.query(queryParams, queryStructNames), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return Passthru.from_json(response.content)


            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_about(self, ) -> SystemAbout:
        try:
            pathParams = {}

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/system/about", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return SystemAbout.from_json(response.content)


            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
backend_cronjob automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from common_metadata import CommonMetadata
from backend_cronjob_error import BackendCronjobError
@dataclass_json
@dataclass
class BackendCronjob:
    id: int
    name: str
    cron: str
    action: str
    execute_date: datetime.datetime
    exit_code: int
    metadata: CommonMetadata
    errors: List[BackendCronjobError]



"""
system_route automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from system_route_path import SystemRoutePath
@dataclass_json
@dataclass
class SystemRoute:
    routes: SystemRoutePath



"""
backend_dashboard automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_statistic_chart import BackendStatisticChart
from backend_dashboard_apps import BackendDashboardApps
from backend_dashboard_requests import BackendDashboardRequests
from backend_dashboard_users import BackendDashboardUsers
from backend_dashboard_transactions import BackendDashboardTransactions
@dataclass_json
@dataclass
class BackendDashboard:
    errors_per_operation: BackendStatisticChart
    incoming_requests: BackendStatisticChart
    incoming_transactions: BackendStatisticChart
    most_used_operations: BackendStatisticChart
    time_per_operation: BackendStatisticChart
    latest_apps: BackendDashboardApps
    latest_requests: BackendDashboardRequests
    latest_users: BackendDashboardUsers
    latest_transactions: BackendDashboardTransactions



"""
backend_page automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendPage:
    id: int
    status: int
    title: str
    slug: str
    content: str
    metadata: CommonMetadata



"""
backend_plan automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendPlan:
    id: int
    name: str
    description: str
    price: float
    points: int
    period: int
    external_id: str
    scopes: List[str]
    metadata: CommonMetadata



"""
CommonMessageException automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import sdkgen

class CommonMessageException(sdkgen.KnownStatusCodeException) {

    def __init__(self, payload: CommonMessage):
        self.payload = payload
    pass

}



"""
backend_marketplace_collection_apps automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Dict
from backend_marketplace_remote_app import BackendMarketplaceRemoteApp
class BackendMarketplaceCollectionApps(Dict[str, BackendMarketplaceRemoteApp]):
    pass



"""
backend_dashboard_users automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from common_collection import CommonCollection
from backend_dashboard_user import BackendDashboardUser
@dataclass_json
@dataclass
class BackendDashboardUsers(CommonCollection[BackendDashboardUser]):
    pass



"""
backend_generator_index_providers automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_generator_index_provider import BackendGeneratorIndexProvider
@dataclass_json
@dataclass
class BackendGeneratorIndexProviders:
    providers: List[BackendGeneratorIndexProvider]



"""
backend_sdk_generate automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendSdkGenerate:
    format: str
    config: str



"""
backend_marketplace_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_marketplace_collection_apps import BackendMarketplaceCollectionApps
@dataclass_json
@dataclass
class BackendMarketplaceCollection:
    apps: BackendMarketplaceCollectionApps



"""
backend_operation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_operation_parameters import BackendOperationParameters
from backend_operation_throws import BackendOperationThrows
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendOperation:
    id: int
    status: int
    active: bool
    public: bool
    stability: int
    description: str
    http_method: str
    http_path: str
    http_code: int
    name: str
    parameters: BackendOperationParameters
    incoming: str
    outgoing: str
    throws: BackendOperationThrows
    action: str
    costs: int
    scopes: List[str]
    metadata: CommonMetadata



"""
ConsumerTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from consumer_account_tag import ConsumerAccountTag
from consumer_app_tag import ConsumerAppTag
from consumer_event_tag import ConsumerEventTag
from consumer_grant_tag import ConsumerGrantTag
from consumer_identity_tag import ConsumerIdentityTag
from consumer_log_tag import ConsumerLogTag
from consumer_page_tag import ConsumerPageTag
from consumer_payment_tag import ConsumerPaymentTag
from consumer_plan_tag import ConsumerPlanTag
from consumer_scope_tag import ConsumerScopeTag
from consumer_token_tag import ConsumerTokenTag
from consumer_transaction_tag import ConsumerTransactionTag
from consumer_webhook_tag import ConsumerWebhookTag

class ConsumerTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass

    def identity(self) -> ConsumerIdentityTag:
        return ConsumerIdentityTag(
            this.http_client,
            this.parser
        )
    pass

    def account(self) -> ConsumerAccountTag:
        return ConsumerAccountTag(
            this.http_client,
            this.parser
        )
    pass

    def transaction(self) -> ConsumerTransactionTag:
        return ConsumerTransactionTag(
            this.http_client,
            this.parser
        )
    pass

    def webhook(self) -> ConsumerWebhookTag:
        return ConsumerWebhookTag(
            this.http_client,
            this.parser
        )
    pass

    def token(self) -> ConsumerTokenTag:
        return ConsumerTokenTag(
            this.http_client,
            this.parser
        )
    pass

    def scope(self) -> ConsumerScopeTag:
        return ConsumerScopeTag(
            this.http_client,
            this.parser
        )
    pass

    def plan(self) -> ConsumerPlanTag:
        return ConsumerPlanTag(
            this.http_client,
            this.parser
        )
    pass

    def payment(self) -> ConsumerPaymentTag:
        return ConsumerPaymentTag(
            this.http_client,
            this.parser
        )
    pass

    def page(self) -> ConsumerPageTag:
        return ConsumerPageTag(
            this.http_client,
            this.parser
        )
    pass

    def log(self) -> ConsumerLogTag:
        return ConsumerLogTag(
            this.http_client,
            this.parser
        )
    pass

    def grant(self) -> ConsumerGrantTag:
        return ConsumerGrantTag(
            this.http_client,
            this.parser
        )
    pass

    def event(self) -> ConsumerEventTag:
        return ConsumerEventTag(
            this.http_client,
            this.parser
        )
    pass

    def app(self) -> ConsumerAppTag:
        return ConsumerAppTag(
            this.http_client,
            this.parser
        )
    pass





"""
consumer_identity_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from common_collection import CommonCollection
from consumer_identity import ConsumerIdentity
@dataclass_json
@dataclass
class ConsumerIdentityCollection(CommonCollection[ConsumerIdentity]):
    pass



"""
backend_action_execute_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_action_execute_response_headers import BackendActionExecuteResponseHeaders
from backend_action_execute_response_body import BackendActionExecuteResponseBody
@dataclass_json
@dataclass
class BackendActionExecuteResponse:
    status_code: int
    headers: BackendActionExecuteResponseHeaders
    body: BackendActionExecuteResponseBody



"""
backend_scope_categories automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_scope_category import BackendScopeCategory
@dataclass_json
@dataclass
class BackendScopeCategories:
    categories: List[BackendScopeCategory]



"""
consumer_webhook_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerWebhookCreate:
    event: str
    name: str
    endpoint: str



"""
backend_identity_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_identity_index_entry import BackendIdentityIndexEntry
@dataclass_json
@dataclass
class BackendIdentityIndex:
    providers: List[BackendIdentityIndexEntry]



"""
common_form_element automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class CommonFormElement:
    element: str
    name: str
    title: str
    help: str



"""
consumer_log automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerLog:
    id: int
    app_id: int
    ip: str
    user_agent: str
    method: str
    path: str
    header: str
    body: str
    date: datetime.datetime



"""
common_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
@dataclass_json
@dataclass
class CommonCollection:
    total_results: int
    start_index: int
    items_per_page: int
    entry: List[T]



"""
backend_account_change_password automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendAccountChangePassword:
    old_password: str
    new_password: str
    verify_password: str



"""
backend_action_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_action_index_entry import BackendActionIndexEntry
@dataclass_json
@dataclass
class BackendActionIndex:
    actions: List[BackendActionIndexEntry]



"""
common_form_element_select_option automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class CommonFormElementSelectOption:
    key: str
    value: str



"""
consumer_plan_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from common_collection import CommonCollection
from consumer_plan import ConsumerPlan
@dataclass_json
@dataclass
class ConsumerPlanCollection(CommonCollection[ConsumerPlan]):
    pass



"""
backend_connection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_connection_config import BackendConnectionConfig
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendConnection:
    id: int
    name: str
    _class: str
    config: BackendConnectionConfig
    metadata: CommonMetadata



"""
consumer_user_plan automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerUserPlan:
    id: int
    name: str
    price: int
    points: int
    period: int



"""
backend_connection_introspection_entities automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
@dataclass_json
@dataclass
class BackendConnectionIntrospectionEntities:
    entities: List[str]



"""
BackendTokenTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from backend_token import BackendToken
from backend_token_collection import BackendTokenCollection
from common_message_exception import CommonMessageException

class BackendTokenTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def get(self, token_id: str) -> BackendToken:
        try:
            pathParams = {}
            pathParams["token_id"] = token_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/token/$token_id<[0-9]+>", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendToken.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_all(self, start_index: int, count: int, search: str, _from: str, to: str, app_id: int, user_id: int, status: int, scope: str, ip: str) -> BackendTokenCollection:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["status"] = status
            queryParams["scope"] = scope
            queryParams["ip"] = ip

            queryStructNames = [];

            url = self.parser.url("/backend/token", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendTokenCollection.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
backend_webhook_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendWebhookResponse:
    id: int
    status: int
    code: int
    attempts: int
    error: str
    execute_date: datetime.datetime



"""
system_schema_form automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Any
from typing import Dict
class SystemSchemaForm(Dict[str, Any]):
    pass



"""
backend_user automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_app import BackendApp
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendUser:
    id: int
    role_id: int
    plan_id: int
    status: int
    name: str
    email: str
    points: int
    scopes: List[str]
    apps: List[BackendApp]
    metadata: CommonMetadata
    date: datetime.datetime



"""
consumer_payment_portal_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerPaymentPortalRequest:
    return_url: str



"""
consumer_token_update automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerTokenUpdate:
    name: str
    expire: datetime.datetime



"""
backend_scope_operation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendScopeOperation:
    operation_id: int
    allow: bool



"""
backend_identity_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_identity import BackendIdentity
@dataclass_json
@dataclass
class BackendIdentityCreate(BackendIdentity):



"""
backend_cronjob_error automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendCronjobError:
    message: str
    trace: str
    file: str
    line: int



"""
backend_scope_category_scope automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendScopeCategoryScope:
    id: int
    name: str
    description: str



"""
backend_rate_allocation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendRateAllocation:
    id: int
    operation_id: int
    user_id: int
    plan_id: int
    app_id: int
    authenticated: bool



"""
backend_generator_provider automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_generator_provider_config import BackendGeneratorProviderConfig
@dataclass_json
@dataclass
class BackendGeneratorProvider:
    path: str
    scopes: List[str]
    public: bool
    config: BackendGeneratorProviderConfig



"""
BackendGeneratorTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from backend_generator_index_providers import BackendGeneratorIndexProviders
from backend_generator_provider import BackendGeneratorProvider
from backend_generator_provider_changelog import BackendGeneratorProviderChangelog
from backend_generator_provider_config import BackendGeneratorProviderConfig
from common_form_container import CommonFormContainer
from common_message import CommonMessage
from common_message_exception import CommonMessageException

class BackendGeneratorTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def get_changelog(self, provider: str, payload: BackendGeneratorProviderConfig) -> BackendGeneratorProviderChangelog:
        try:
            pathParams = {}
            pathParams["provider"] = provider

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/generator/:provider", pathParams)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.put(url, headers=headers, params=this.parser.query(queryParams, queryStructNames), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return BackendGeneratorProviderChangelog.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def execute_provider(self, provider: str, payload: BackendGeneratorProvider) -> CommonMessage:
        try:
            pathParams = {}
            pathParams["provider"] = provider

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/generator/:provider", pathParams)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=this.parser.query(queryParams, queryStructNames), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_form(self, provider: str) -> CommonFormContainer:
        try:
            pathParams = {}
            pathParams["provider"] = provider

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/generator/:provider", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonFormContainer.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_classes(self, ) -> BackendGeneratorIndexProviders:
        try:
            pathParams = {}

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/generator", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendGeneratorIndexProviders.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
consumer_token_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
@dataclass_json
@dataclass
class ConsumerTokenCreate:
    name: str
    scope: List[str]
    expire: datetime.datetime



"""
consumer_authorize_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from consumer_authorize_response_token import ConsumerAuthorizeResponseToken
@dataclass_json
@dataclass
class ConsumerAuthorizeResponse:
    type: str
    token: ConsumerAuthorizeResponseToken
    code: str
    redirect_uri: str



"""
SystemConnectionTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from common_message import CommonMessage

class SystemConnectionTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def callback(self, name: str) -> CommonMessage:
        try:
            pathParams = {}
            pathParams["name"] = name

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/system/connection/:name/callback", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.from_json(response.content)


            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
common_form_element_select automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from common_form_element import CommonFormElement
from common_form_element_select_option import CommonFormElementSelectOption
@dataclass_json
@dataclass
class CommonFormElementSelect(CommonFormElement):
    options: List[CommonFormElementSelectOption]



"""
AuthorizationTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from backend_user import BackendUser
from common_message import CommonMessage
from common_message_exception import CommonMessageException

class AuthorizationTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def get_whoami(self, ) -> BackendUser:
        try:
            pathParams = {}

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/authorization/whoami", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendUser.from_json(response.content)

            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def revoke(self, ) -> CommonMessage:
        try:
            pathParams = {}

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/authorization/revoke", pathParams)

            headers = {}

            response = self.http_client.post(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.from_json(response.content)

            if response.status_code == 400:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
backend_audit automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_app import BackendApp
from backend_user import BackendUser
from backend_audit_object import BackendAuditObject
@dataclass_json
@dataclass
class BackendAudit:
    id: int
    app: BackendApp
    user: BackendUser
    event: str
    ip: str
    message: str
    content: BackendAuditObject
    date: datetime.datetime



"""
system_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from system_schema_type_schema import SystemSchemaTypeSchema
from system_schema_form import SystemSchemaForm
@dataclass_json
@dataclass
class SystemSchema:
    schema: SystemSchemaTypeSchema
    form: SystemSchemaForm



"""
backend_event automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendEvent:
    id: int
    name: str
    description: str
    schema: str
    metadata: CommonMetadata



"""
backend_action_execute_response_headers automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Dict
class BackendActionExecuteResponseHeaders(Dict[str, str]):
    pass



"""
consumer_payment_checkout_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerPaymentCheckoutRequest:
    plan_id: int
    return_url: str



"""
system_about_link automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class SystemAboutLink:
    rel: str
    href: str



"""
backend_page_update automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_page import BackendPage
@dataclass_json
@dataclass
class BackendPageUpdate(BackendPage):



"""
consumer_authorize_meta automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from consumer_scope import ConsumerScope
@dataclass_json
@dataclass
class ConsumerAuthorizeMeta:
    name: str
    url: str
    scopes: List[ConsumerScope]



"""
backend_dashboard_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendDashboardRequest:
    id: int
    path: str
    ip: str
    date: datetime.datetime



"""
consumer_user_refresh automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerUserRefresh:
    refresh_token: str



"""
consumer_page_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from common_collection import CommonCollection
from consumer_page import ConsumerPage
@dataclass_json
@dataclass
class ConsumerPageCollection(CommonCollection[ConsumerPage]):
    pass



"""
BackendSchemaTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from backend_schema import BackendSchema
from backend_schema_collection import BackendSchemaCollection
from backend_schema_create import BackendSchemaCreate
from backend_schema_form import BackendSchemaForm
from backend_schema_preview_response import BackendSchemaPreviewResponse
from backend_schema_update import BackendSchemaUpdate
from common_message import CommonMessage
from common_message_exception import CommonMessageException

class BackendSchemaTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def delete(self, schema_id: str) -> CommonMessage:
        try:
            pathParams = {}
            pathParams["schema_id"] = schema_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/schema/$schema_id<[0-9]+|^~>", pathParams)

            headers = {}

            response = self.http_client.delete(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 410:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def update(self, schema_id: str, payload: BackendSchemaUpdate) -> CommonMessage:
        try:
            pathParams = {}
            pathParams["schema_id"] = schema_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/schema/$schema_id<[0-9]+|^~>", pathParams)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.put(url, headers=headers, params=this.parser.query(queryParams, queryStructNames), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.from_json(response.content)

            if response.status_code == 400:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 410:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get(self, schema_id: str) -> BackendSchema:
        try:
            pathParams = {}
            pathParams["schema_id"] = schema_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/schema/$schema_id<[0-9]+|^~>", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendSchema.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 410:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def update_form(self, schema_id: str, payload: BackendSchemaForm) -> CommonMessage:
        try:
            pathParams = {}
            pathParams["schema_id"] = schema_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/schema/form/$schema_id<[0-9]+>", pathParams)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.put(url, headers=headers, params=this.parser.query(queryParams, queryStructNames), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.from_json(response.content)

            if response.status_code == 400:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 404:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 410:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_preview(self, schema_id: str) -> BackendSchemaPreviewResponse:
        try:
            pathParams = {}
            pathParams["schema_id"] = schema_id

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/schema/preview/:schema_id", pathParams)

            headers = {}

            response = self.http_client.post(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendSchemaPreviewResponse.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def create(self, payload: BackendSchemaCreate) -> CommonMessage:
        try:
            pathParams = {}

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/backend/schema", pathParams)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=this.parser.query(queryParams, queryStructNames), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.from_json(response.content)

            if response.status_code == 400:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_all(self, start_index: int, count: int, search: str) -> BackendSchemaCollection:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search

            queryStructNames = [];

            url = self.parser.url("/backend/schema", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendSchemaCollection.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
system_health_check automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class SystemHealthCheck:
    healthy: bool
    error: str



"""
system_route_path automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Dict
from system_route_method import SystemRouteMethod
class SystemRoutePath(Dict[str, SystemRouteMethod]):
    pass



"""
backend_connection_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_connection_index_entry import BackendConnectionIndexEntry
@dataclass_json
@dataclass
class BackendConnectionIndex:
    connections: List[BackendConnectionIndexEntry]



"""
backend_generator_provider_changelog automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_schema import BackendSchema
from backend_action import BackendAction
from backend_operation import BackendOperation
@dataclass_json
@dataclass
class BackendGeneratorProviderChangelog:
    schemas: List[BackendSchema]
    actions: List[BackendAction]
    operations: List[BackendOperation]



"""
backend_action_execute_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_action_execute_request_body import BackendActionExecuteRequestBody
@dataclass_json
@dataclass
class BackendActionExecuteRequest:
    method: str
    uri_fragments: str
    parameters: str
    headers: str
    body: BackendActionExecuteRequestBody



"""
ConsumerPaymentTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from common_message_exception import CommonMessageException
from consumer_payment_checkout_request import ConsumerPaymentCheckoutRequest
from consumer_payment_checkout_response import ConsumerPaymentCheckoutResponse
from consumer_payment_portal_request import ConsumerPaymentPortalRequest
from consumer_payment_portal_response import ConsumerPaymentPortalResponse

class ConsumerPaymentTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def checkout(self, provider: str, payload: ConsumerPaymentCheckoutRequest) -> ConsumerPaymentCheckoutResponse:
        try:
            pathParams = {}
            pathParams["provider"] = provider

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/consumer/payment/:provider/checkout", pathParams)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=this.parser.query(queryParams, queryStructNames), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return ConsumerPaymentCheckoutResponse.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def portal(self, provider: str, payload: ConsumerPaymentPortalRequest) -> ConsumerPaymentPortalResponse:
        try:
            pathParams = {}
            pathParams["provider"] = provider

            queryParams = {}

            queryStructNames = [];

            url = self.parser.url("/consumer/payment/:provider/portal", pathParams)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=this.parser.query(queryParams, queryStructNames), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return ConsumerPaymentPortalResponse.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
backend_dashboard_transaction automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendDashboardTransaction:
    id: int
    status: str
    provider: str
    transaction_id: str
    amount: float
    date: datetime.datetime



"""
common_form_container automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from typing import Union
from common_form_element_input import CommonFormElementInput
from common_form_element_select import CommonFormElementSelect
from common_form_element_tag import CommonFormElementTag
from common_form_element_text_area import CommonFormElementTextArea
@dataclass_json
@dataclass
class CommonFormContainer:
    element: List[Union[CommonFormElementInput, CommonFormElementSelect, CommonFormElementTag, CommonFormElementTextArea]]



"""
backend_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from common_metadata import CommonMetadata
from backend_token import BackendToken
@dataclass_json
@dataclass
class BackendApp:
    id: int
    user_id: int
    status: int
    name: str
    url: str
    parameters: str
    app_key: str
    app_secret: str
    metadata: CommonMetadata
    date: datetime.datetime
    scopes: List[str]
    tokens: List[BackendToken]



"""
backend_log_error automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendLogError:
    id: int
    message: int
    trace: str
    file: str
    line: int



"""
backend_identity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_identity_config import BackendIdentityConfig
@dataclass_json
@dataclass
class BackendIdentity:
    id: int
    app_id: int
    role_id: int
    name: str
    icon: str
    _class: str
    config: BackendIdentityConfig
    allow_create: bool



"""
system_route_method automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Dict
class SystemRouteMethod(Dict[str, str]):
    pass



"""
consumer_authorize_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerAuthorizeRequest:
    response_type: str
    client_id: str
    redirect_uri: str
    scope: str
    state: str
    allow: bool



"""
backend_action automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_action_config import BackendActionConfig
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendAction:
    id: int
    status: int
    name: str
    _class: str
    async: bool
    config: BackendActionConfig
    metadata: CommonMetadata



"""
backend_connection_introspection_entity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_connection_introspection_entity_row import BackendConnectionIntrospectionEntityRow
@dataclass_json
@dataclass
class BackendConnectionIntrospectionEntity:
    name: str
    headers: List[str]
    rows: List[BackendConnectionIntrospectionEntityRow]



"""
consumer_webhook automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from consumer_webhook_response import ConsumerWebhookResponse
@dataclass_json
@dataclass
class ConsumerWebhook:
    id: int
    status: int
    event: str
    name: str
    endpoint: str
    responses: List[ConsumerWebhookResponse]



"""
common_form_element_text_area automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from common_form_element import CommonFormElement
@dataclass_json
@dataclass
class CommonFormElementTextArea(CommonFormElement):
    mode: str



"""
backend_rate automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from backend_rate_allocation import BackendRateAllocation
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendRate:
    id: int
    priority: int
    name: str
    rate_limit: int
    timespan: datetime.timedelta
    allocation: List[BackendRateAllocation]
    metadata: CommonMetadata



"""
consumer_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
@dataclass_json
@dataclass
class ConsumerToken:
    id: int
    status: int
    name: str
    scopes: List[str]
    ip: str
    expire: datetime.datetime
    date: datetime.datetime



"""
backend_marketplace_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendMarketplaceApp:
    version: str
    description: str
    screenshot: str
    website: str
    download_url: str
    sha_hash: str
    start_url: str



"""
backend_operation_parameters automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import Dict
from backend_operation_schema import BackendOperationSchema
class BackendOperationParameters(Dict[str, BackendOperationSchema]):
    pass



"""
BackendStatisticTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen

from backend_statistic_chart import BackendStatisticChart
from backend_statistic_count import BackendStatisticCount
from common_message_exception import CommonMessageException

class BackendStatisticTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)
    pass


    def get_used_points(self, start_index: int, count: int, search: str, _from: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["operationId"] = operation_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/statistic/used_points", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_time_per_operation(self, start_index: int, count: int, search: str, _from: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["operationId"] = operation_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/statistic/time_per_operation", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_time_average(self, start_index: int, count: int, search: str, _from: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["operationId"] = operation_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/statistic/time_average", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_most_used_operations(self, start_index: int, count: int, search: str, _from: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["operationId"] = operation_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/statistic/most_used_operations", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_most_used_apps(self, start_index: int, count: int, search: str, _from: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["operationId"] = operation_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/statistic/most_used_apps", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_issued_tokens(self, start_index: int, count: int, search: str, _from: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["operationId"] = operation_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/statistic/issued_tokens", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_incoming_transactions(self, start_index: int, count: int, search: str, _from: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["operationId"] = operation_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/statistic/incoming_transactions", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_incoming_requests(self, start_index: int, count: int, search: str, _from: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["operationId"] = operation_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/statistic/incoming_requests", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_errors_per_operation(self, start_index: int, count: int, search: str, _from: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["operationId"] = operation_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/statistic/errors_per_operation", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass

    def get_count_requests(self, start_index: int, count: int, search: str, _from: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticCount:
        try:
            pathParams = {}

            queryParams = {}
            queryParams["startIndex"] = start_index
            queryParams["count"] = count
            queryParams["search"] = search
            queryParams["from"] = _from
            queryParams["to"] = to
            queryParams["operationId"] = operation_id
            queryParams["appId"] = app_id
            queryParams["userId"] = user_id
            queryParams["ip"] = ip
            queryParams["userAgent"] = user_agent
            queryParams["method"] = method
            queryParams["path"] = path
            queryParams["header"] = header
            queryParams["body"] = body

            queryStructNames = [];

            url = self.parser.url("/backend/statistic/count_requests", pathParams)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=this.parser.query(queryParams, queryStructNames))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticCount.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(CommonMessage.from_json(response.content))
            if response.status_code == 500:
                raise CommonMessageException(CommonMessage.from_json(response.content))

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except Exception as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))
    pass





"""
backend_operation_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendOperationSchema:
    description: str
    type: str
    format: str
    enum: str



"""
backend_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from backend_schema_source import BackendSchemaSource
from backend_schema_form import BackendSchemaForm
from common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendSchema:
    id: int
    status: int
    name: str
    source: BackendSchemaSource
    form: BackendSchemaForm
    metadata: CommonMetadata



"""
backend_statistic_count automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendStatisticCount:
    count: int
    _from: datetime.datetime
    to: datetime.datetime



"""
consumer_user_register automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerUserRegister:
    name: str
    email: str
    password: str
    captcha: str



"""
consumer_token_access_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class ConsumerTokenAccessToken:
    access_token: str
    token_type: str
    expires_in: int
    refresh_token: str
    scope: str



"""
system_about automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
from typing import List
from system_about_apps import SystemAboutApps
from system_about_link import SystemAboutLink
@dataclass_json
@dataclass
class SystemAbout:
    api_version: str
    title: str
    description: str
    terms_of_service: str
    contact_name: str
    contact_url: str
    contact_email: str
    license_name: str
    license_url: str
    payment_currency: str
    categories: List[str]
    scopes: List[str]
    apps: SystemAboutApps
    links: List[SystemAboutLink]



"""
backend_trash_restore automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass
from dataclasses_json import dataclass_json
@dataclass_json
@dataclass
class BackendTrashRestore:
    id: int



"""
Client automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import sdkgen

from authorization_tag import AuthorizationTag
from system_tag import SystemTag
from consumer_tag import ConsumerTag
from backend_tag import BackendTag

class Client(sdkgen.ClientAbstract):
    def __init__(self, base_url: str, credentials: sdkgen.CredentialsInterface):
        super().__init__(base_url, credentials)
    pass

    def authorization(self) -> AuthorizationTag:
        return AuthorizationTag(
            self.http_client,
            self.parser
        )
    pass

    def system(self) -> SystemTag:
        return SystemTag(
            self.http_client,
            self.parser
        )
    pass

    def consumer(self) -> ConsumerTag:
        return ConsumerTag(
            self.http_client,
            self.parser
        )
    pass

    def backend(self) -> BackendTag:
        return BackendTag(
            self.http_client,
            self.parser
        )
    pass



    @staticmethod
    def build(clientId: str, clientSecret: str, tokenStore: sdkgen.TokenStoreInterface, scopes: List[str]):
        return Client("https://api.typehub.cloud/", sdkgen.OAuth2(clientId, clientSecret, "https://api.typehub.cloud/authorization/token", "", tokenStore, scopes))
    pass
